summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/dependencies/poppler-tqt/poppler-private.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/dependencies/poppler-tqt/poppler-private.cc')
-rw-r--r--kfile-plugins/dependencies/poppler-tqt/poppler-private.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/kfile-plugins/dependencies/poppler-tqt/poppler-private.cc b/kfile-plugins/dependencies/poppler-tqt/poppler-private.cc
index 7e366014..445417a2 100644
--- a/kfile-plugins/dependencies/poppler-tqt/poppler-private.cc
+++ b/kfile-plugins/dependencies/poppler-tqt/poppler-private.cc
@@ -31,11 +31,11 @@
namespace Poppler {
/* borrowed from kpdf */
-TQString unicodeToTQString(Unicode* u, int len)
+TQString tqunicodeToTQString(Unicode* u, int len)
{
TQString ret;
ret.setLength(len);
- TQChar* qch = (TQChar*) ret.unicode();
+ TQChar* qch = (TQChar*) ret.tqunicode();
for (;len;--len)
*qch++ = (TQChar) *u++;
return ret;
@@ -69,7 +69,7 @@ TQString UnicodeParsedString(GooString *s1)
u = s1->getChar(i) & 0xff;
++i;
}
- result += unicodeToTQString( &u, 1 );
+ result += tqunicodeToTQString( &u, 1 );
}
return result;
}
@@ -79,7 +79,7 @@ GooString *TQStringToGooString(const TQString &s)
int len = s.length();
char *cstring = (char *)gmallocn(s.length(), sizeof(char));
for (int i = 0; i < len; ++i)
- cstring[i] = s.at(i).unicode();
+ cstring[i] = s.tqat(i).tqunicode();
GooString *ret = new GooString(cstring, len);
gfree(cstring);
return ret;
@@ -98,7 +98,7 @@ void DocumentData::addTocChildren( TQDomDocument * docSyn, TQDomNode * parent, G
TQString name;
Unicode * uniChar = outlineItem->getTitle();
int titleLength = outlineItem->getTitleLength();
- name = unicodeToTQString(uniChar, titleLength);
+ name = tqunicodeToTQString(uniChar, titleLength);
if ( name.isEmpty() )
continue;
@@ -136,11 +136,11 @@ void DocumentData::addTocChildren( TQDomDocument * docSyn, TQDomNode * parent, G
}
}
// 3. recursively descend over children
outlineItem->open();
- GooList * children = outlineItem->getKids();
- if ( children )
- addTocChildren( docSyn, &item, children );
+ GooList * tqchildren = outlineItem->getKids();
+ if ( tqchildren )
+ addTocChildren( docSyn, &item, tqchildren );
}
}
@@ -136,11 +136,11 @@ void DocumentData::addTocChildren( TQDomDocument * docSyn, TQDomNode * parent, G
}
}
- // 3. recursively descend over children
+ // 3. recursively descend over tqchildren
outlineItem->open();